==> dif-core-2.1.9-1-20151124.173937-3-sources.jar: pt/digitalis/dif/utils/cache/CacheInfo.java <==
/**
 * 2009, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.utils.cache;

/**
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created 16 de Mar de 2011
 */
public class CacheInfo {

    /** Cache life time in seconds */
    private long durationInSeconds;

    /** the cache scope */
    private CacheScope scope;

    /**
     * @param durationInSeconds
     * @param scope
     */
    public CacheInfo(CacheScope scope, long durationInSeconds)
    {
        super();
        this.durationInSeconds = durationInSeconds;
        this.scope = scope;
    }

    /**
     * Inspector for the 'durationInSeconds' attribute.
     * 
     * @return the durationInSeconds value
     */
    protected long getDurationInSeconds()
    {
        return durationInSeconds;
    }

    /**
     * Inspector for the 'scope' attribute.
     * 
     * @return the scope value
     */
    protected CacheScope getScope()
    {
        return scope;
    }

    /**
     * Modifier for the 'durationInSeconds' attribute.
     * 
     * @param durationInSeconds
     *            the new durationInSeconds value to set
     */
    protected void setDurationInSeconds(long durationInSeconds)
    {
        this.durationInSeconds = durationInSeconds;
    }

    /**
     * Modifier for the 'scope' attribute.
     * 
     * @param scope
     *            the new scope value to set
     */
    protected void setScope(CacheScope scope)
    {
        this.scope = scope;
    }
}

==> dif-core-2.6.0-sources.jar: pt/digitalis/dif/utils/cache/CacheInfo.java <==
/**
 * 2009, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de Informatica, Lda. Estrada de Paco de Arcos
 * num.9 - Piso -1 2780-666 Paco de Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999 http://www.digitalis.pt
 */

package pt.digitalis.dif.utils.cache;

/**
 * @author Pedro Viegas <a href="mailto:pviegas@digitalis.pt">pviegas@digitalis.pt</a><br/>
 * @created 16 de Mar de 2011
 */
public class CacheInfo
{

    /** Cache life time in seconds */
    private long durationInSeconds;

    /** the cache scope */
    private CacheScope scope;

    /**
     * @param durationInSeconds
     * @param scope
     */
    public CacheInfo(CacheScope scope, long durationInSeconds)
    {
        super();
        this.durationInSeconds = durationInSeconds;
        this.scope = scope;
    }

    /**
     * Inspector for the 'durationInSeconds' attribute.
     *
     * @return the durationInSeconds value
     */
    protected long getDurationInSeconds()
    {
        return durationInSeconds;
    }

    /**
     * Modifier for the 'durationInSeconds' attribute.
     *
     * @param durationInSeconds the new durationInSeconds value to set
     */
    protected void setDurationInSeconds(long durationInSeconds)
    {
        this.durationInSeconds = durationInSeconds;
    }

    /**
     * Inspector for the 'scope' attribute.
     *
     * @return the scope value
     */
    protected CacheScope getScope()
    {
        return scope;
    }

    /**
     * Modifier for the 'scope' attribute.
     *
     * @param scope the new scope value to set
     */
    protected void setScope(CacheScope scope)
    {
        this.scope = scope;
    }
}
